import { Calendar, CalendarEvent, AttachmentRequest, Attachment, ChannelSendPolicy, ChannelType, Chat, ChatMap, InternalMessage, Invite, Message, MessageAttachment, MessageAttachmentData, MessageStatus, AttachmentStatus, RoomInfo, SfuEvent, State, User, UserEmail, UserId, UserNickname, UserSpecificChatInfo, ChatReceivePolicy } from "./constants";
import { RoomExtended } from "./room-extended";
import { Verbosity } from "./logger";
import { SendingAttachmentsHandler } from "./sending-attachments-handler";
declare type NotifyUnion = InternalMessage | Message | MessageStatus | AttachmentStatus | Array<User> | Calendar | UserSpecificChatInfo | Invite | User | ChatMap | Chat | ArrayBuffer | CalendarEvent | Attachment;
export declare class SfuExtended {
    #private;
    constructor(logLevel?: Verbosity);
    connect(options: {
        url: string;
        username: UserId;
        password: string;
        nickname: UserNickname;
        timeout?: number;
        binaryChunkSize?: number;
    }): Promise<{
        username: UserId;
        nickname: UserNickname;
        pmi: string;
    }>;
    sendMessage(msg: {
        body?: string;
        to?: string;
        chatId: string;
        attachments?: Array<MessageAttachment>;
    }): Promise<MessageStatus>;
    getSendingAttachmentsHandler(attachments: Array<MessageAttachmentData>, messageId: string): SendingAttachmentsHandler;
    getMessageAttachment(attachment: AttachmentRequest): Promise<Attachment>;
    markMessageRead(msg: {
        id: string;
        chatId: string;
    }): Promise<UserSpecificChatInfo>;
    markMessageUnread(msg: {
        id: string;
        chatId: string;
    }): Promise<UserSpecificChatInfo>;
    getUserList(): Promise<User[]>;
    getUserCalendar(): Promise<Calendar>;
    addCalendarEvent(event: {
        title: string;
        description: string;
        start: number;
        end: number;
        recurring: boolean;
        accessCode?: string;
        waitingRoom: boolean;
        usePMI: boolean;
        ownerVideo: boolean;
        participantVideo: boolean;
    }): Promise<CalendarEvent>;
    removeCalendarEvent(event: {
        id: string;
    }): Promise<CalendarEvent>;
    updateCalendarEvent(event: {
        id: string;
        title: string;
        description: string;
        start: number;
        end: number;
        recurring: boolean;
        accessCode?: string;
        waitingRoom: boolean;
        usePMI: boolean;
        ownerVideo: boolean;
        participantVideo: boolean;
    }): Promise<CalendarEvent>;
    getUserChats(): Promise<ChatMap>;
    getPublicChannels(): Promise<ChatMap>;
    loadChat(chat: {
        id: string;
    }): Promise<Chat>;
    loadChatMessages(params: {
        chatId: string;
        limit?: number;
        timeFrame: {
            start: number;
            end: number;
        };
    }): Promise<Message[]>;
    searchChatMessages(params: {
        chatId: string;
        searchString: string;
        searchId?: string;
        limit?: number;
    }): Promise<Message[]>;
    createChat(chat: {
        id?: string;
        name?: string;
        members?: Array<UserId>;
        favourite?: boolean;
        channel?: boolean;
        channelType?: ChannelType;
        channelSendPolicy?: ChannelSendPolicy;
        sendPermissionList?: Array<string>;
        allowedToAddExternalUser?: boolean;
    }): Promise<UserSpecificChatInfo>;
    deleteChat(chat: {
        id: string;
    }): Promise<void>;
    renameChat(chat: {
        id: string;
        name: string;
    }): Promise<void>;
    addMemberToChat(chat: {
        id: string;
        member: UserId;
    }): Promise<UserSpecificChatInfo>;
    removeMemberFromChat(chat: {
        id: string;
        member: UserId;
    }): Promise<UserSpecificChatInfo>;
    inviteContact(invite: {
        to: UserId | UserEmail;
    }): Promise<User>;
    addContactToFavourites(contact: {
        id: UserId;
    }): Promise<User>;
    removeContactFromFavourites(contact: {
        id: UserId;
    }): Promise<User>;
    confirmContact(invite: {
        id: string;
        from: UserId;
        to: UserId;
    }): Promise<User>;
    removeContact(contact: {
        id: UserId;
    }): Promise<User>;
    updateChannelSendPolicy(channel: {
        id: string;
        channelSendPolicy: ChannelSendPolicy;
    }): Promise<UserSpecificChatInfo>;
    updateChatReceivePolicy(channel: {
        id: string;
        chatReceivePolicy: ChatReceivePolicy;
    }): Promise<UserSpecificChatInfo>;
    addChannelSendPermissionListMember(channel: {
        id: string;
        member: UserId;
    }): Promise<UserSpecificChatInfo>;
    removeChannelSendPermissionListMember(channel: {
        id: string;
        member: UserId;
    }): Promise<UserSpecificChatInfo>;
    updateChatConfiguration(chat: {
        id: string;
        channelType?: ChannelType;
        channelSendPolicy?: ChannelSendPolicy;
        sendPermissionList?: Array<string>;
        allowedToAddExternalUser?: boolean;
    }): Promise<UserSpecificChatInfo>;
    addChatToFavourites(chat: {
        id: string;
    }): Promise<UserSpecificChatInfo>;
    removeChatFromFavourites(chat: {
        id: string;
    }): Promise<UserSpecificChatInfo>;
    createRoom(options: {
        name?: string;
        pin?: string;
        id?: string;
    }): Promise<RoomExtended>;
    createRoomFromEvent(event: {
        id: string;
        title: string;
        description: string;
        start: number;
        end: number;
        recurring: boolean;
        accessCode?: string;
        waitingRoom: boolean;
        usePMI: boolean;
        ownerVideo: boolean;
        participantVideo: boolean;
    }): Promise<RoomExtended>;
    loadActiveRooms(): Promise<RoomInfo[]>;
    roomAvailable(options: {
        id: string;
        pin?: string;
        nickname?: string;
    }): Promise<RoomExtended>;
    roomExists(options: {
        id: string;
        pin?: string;
    }): Promise<void>;
    getRoom(options: {
        id: string;
    }): RoomExtended;
    disconnect(): void;
    user(): {
        username: string;
        nickname: string;
        pmi: string;
    };
    server(): string;
    state(): State;
    on(event: SfuEvent, callback: (arg0: NotifyUnion) => void): SfuExtended;
    off(event: SfuEvent, callback: (arg0: NotifyUnion) => void): SfuExtended;
}
export {};
